@@ -1,7 +1,7 @@
 #' @exportS3Method
 summary.vlmc <- function(object, ...) {
   ctx <- contexts(object, frequency = "detailed")
-  all_length <- sapply(ctx$context, length)
+  all_length <- lengths(ctx$context)
   res <- list(
     state_space = states(object),
     nb = nrow(ctx),
@@ -13,15 +13,19 @@ summary.vlmc <- function(object, ...) {
   structure(res, class = "summary.vlmc")
 }
 
+print_summary_vlmc <- function(x) {
+  cat(paste(" Cutoff: ", signif(x$cutoff, 4), " (quantile: ", signif(x$alpha, 4), ")\n", sep = ""))
+  cat(paste(" Number of contexts:", x$nb, "\n"))
+  cat(paste(" Maximum context length:", x$depth, "\n"))
+  cat(paste(" Average context length:", signif(x$avg_depth, 4), "\n"))
+}
+
 #' @exportS3Method
 print.summary.vlmc <- function(x, ...) {
   cat(paste(
     "VLMC context tree on",
     paste(x$state_space, collapse = ", ")
   ), "\n")
-  cat(paste(" Cutoff: ", signif(x$cutoff, 4), " (quantile: ", x$alpha, ")\n", sep = ""))
-  cat(paste(" Number of contexts:", x$nb, "\n"))
-  cat(paste(" Maximum context length:", x$depth, "\n"))
-  cat(paste(" Average context length:", signif(x$avg_depth, 4), "\n"))
+  print_summary_vlmc(x)
   invisible(x)
 }
